==> igniteui-react-charts-16.6.4.tgz: package/ES5/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
var MarketFacilitationIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        var _this = _super.call(this) || this;
        _this.pb = 1;
        return _this;
    }
    MarketFacilitationIndexIndicator.prototype.get_qp = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_qg = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "qg", {
        get: function () {
            return this.get_qg();
        },
        enumerable: true,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        var _this = _super.call(this) || this;
        _this.pd = 1;
        return _this;
    }
    MarketFacilitationIndexIndicator.prototype.get_qr = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "qr", {
        get: function () {
            return this.get_qr();
        },
        enumerable: true,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_qi = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };
